@@ -2,12 +2,8 @@
 extern crate log;
 
 use env_logger::Builder;
-use stainless_ffmpeg::order::OutputResult::Entry;
-use stainless_ffmpeg::order::*;
-use stainless_ffmpeg::prelude::*;
-use std::env;
-use std::fs::File;
-use std::io::Read;
+use stainless_ffmpeg::{order::OutputResult::Entry, order::*, prelude::*};
+use std::{env, fs::File, io::Read};
 
 fn main() {
   let mut builder = Builder::from_default_env();
@@ -33,8 +29,7 @@ fn main() {
         info!("END OF PROCESS");
         info!("-> {:?} frames processed", results.len());
         for result in results {
-          match result {
-            Entry(entry_map) => {
+          if let Entry(entry_map) = result {
               if let Some(value) = entry_map.get("lavfi.silence_start") {
                 info!("silence start: {}", value);
               }
@@ -44,8 +39,6 @@ fn main() {
               if let Some(value) = entry_map.get("lavfi.r128.I") {
                 info!("Program Loudness: {}", value);
               }
-            }
-            _ => {}
           }
         }
       }
